﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Com.Syncfusion.Charts.Enums;
using Android.Runtime;
using System;
using Android.Content;
using System.Collections.Generic;

namespace Sample
{
    [Activity(Label = "Sample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        ObservableArrayList data;
        SfChart chart;
        CategoryAxis xAxis;
        NumericalAxis yAxis;
        ColumnSeries series;
                 
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            xAxis = new CategoryAxis();
            yAxis = new NumericalAxis();
            series = new ColumnSeries();

            if (bundle != null)
            {
                xAxis.ZoomFactor = bundle.GetFloat("xF", xAxis.ZoomFactor);
                yAxis.ZoomFactor = bundle.GetFloat("yF", yAxis.ZoomFactor);
                xAxis.ZoomPosition = bundle.GetFloat("xP", xAxis.ZoomPosition);
                yAxis.ZoomPosition = bundle.GetFloat("yP", yAxis.ZoomPosition);

                if (bundle.GetBoolean("series"))
                {
                    series.Visibility = Visibility.Visible;
                }
                else
                {
                   series.Visibility = Visibility.Gone;
                }
           
            }

            data = new ObservableArrayList();
            data.Add(new ChartDataPoint("Jan", 10));
            data.Add(new ChartDataPoint("Feb", 20));
            data.Add(new ChartDataPoint("Mar", 25));
            data.Add(new ChartDataPoint("Apr", 18));
            data.Add(new ChartDataPoint("May", 25));

         
            chart = new SfChart(this);
            chart.SetBackgroundColor(Android.Graphics.Color.White);
          
            chart.PrimaryAxis = xAxis;
            chart.SecondaryAxis = yAxis;
                    
            series.DataSource = data;
            series.Label = "India";
            chart.Series.Add(series);
              
            chart.Legend.Visibility = Visibility.Visible;
            chart.Legend.ToggleSeriesVisibility = true;

            ChartZoomPanBehavior zoomPan = new ChartZoomPanBehavior();
            chart.Behaviors.Add(zoomPan);

            // Set our view from the "main" layout resource
            SetContentView(chart);
        }

        protected override void OnSaveInstanceState(Bundle outState)
        {  
            base.OnSaveInstanceState(outState);

            if (series.Visibility == Visibility.Visible)
            {
                outState.PutBoolean("series", true);
            }
            else
            {
                outState.PutBoolean("series", false);
            }

            outState.PutFloat("xF", xAxis.ZoomFactor);
            outState.PutFloat("yF", yAxis.ZoomFactor);
            outState.PutFloat("xP", xAxis.ZoomPosition);
            outState.PutFloat("yP", yAxis.ZoomPosition);
      
        }

    }
}

